@@ -1,26 +1,10 @@
 /**************************************************************************
 
-    begin                : April 30 2004
-	version				 : 1.0 
+    begin                : June 30 2004
+	version				 : 1.2 
     copyright            : (C) 2004 by Gleb Beliakov
     email                : gleb@deakin.edu.au
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-
-
  *   This file contains implementation of  support_vector, SVSetNode and   *
  *   Forest.                                                               *
  *                                                                         *
@@ -43,9 +27,22 @@
 
 	See documentation about the methods used for further information
 
- 
-
-
+ *                                                                         *
+ *   Gleb Beliakov, 2004												   *
+ *                                                                         *
+ * This program is free software; you can redistribute it and/or modify it *
+ * under the terms of the GNU General Public License as published by the   *
+ * Free Software Foundation; either version 2 of the License, or (at your  *
+ * option) any later version.                                              *
+ *                                                                         *
+ * This program is distributed in the hope that it will be useful, but     *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * General Public License for more details.                                *
+ *                                                                         *
+ * You should have received a copy of the GNU General Public License       *
+ * along with this program; if not, write to the Free Software Foundation, *
+ * Inc., 59 Temple Place Suite 330, Boston, MA 02111-1307 USA.             *
  ***************************************************************************/
 
 #include "interpol.h"   
@@ -113,7 +110,7 @@ void	support_vector::SVForm(int Label)
 }
 
 void support_vector::Increment()
-{	ChangeF(funvalue + max(funvalue,1)*Meps);  }
+{	ChangeF(funvalue + max_(funvalue,1)*Meps);  }
 
 short int	support_vector::ChangeF(real newval)
 {
