@@ -1,26 +1,10 @@
 /**************************************************************************
 
-    begin                : April 30 2004
-	version				 : 1.0 
+    begin                : June 30 2004
+	version		 : 1.2 
     copyright            : (C) 2004 by Gleb Beliakov
     email                : gleb@deakin.edu.au
 
-
-     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-
  *   This file contains several classes: support_vector, SVSetNode and     *
  *   Forest.                                                               *
  *                                                                         *
@@ -43,6 +27,22 @@
 
 	See documentation about the methods used for further information
 
+ *                                                                         *
+ *   Gleb Beliakov, 2004												   *
+ *                                                                         *
+ * This program is free software; you can redistribute it and/or modify it *
+ * under the terms of the GNU General Public License as published by the   *
+ * Free Software Foundation; either version 2 of the License, or (at your  *
+ * option) any later version.                                              *
+ *                                                                         *
+ * This program is distributed in the hope that it will be useful, but     *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * General Public License for more details.                                *
+ *                                                                         *
+ * You should have received a copy of the GNU General Public License       *
+ * along with this program; if not, write to the Free Software Foundation, *
+ * Inc., 59 Temple Place Suite 330, Boston, MA 02111-1307 USA.             *
  ***************************************************************************/
 
 
@@ -56,7 +56,7 @@ typedef unsigned long long int ULINT; //this type myst be 8 bytes long
 
 // this is compiler dependent
 // these macros are to cast double to 8 byte integer and back
-#define ULLMASK 0xFFFFFFFF00000000ULL 
+#define ULLMASK 0xFFFFFFFF00000000ULL
 #define d2ulint(a)  (*(ULINT*) &(a))
 #define ulint2d(a) (*(double*) &(a))
 
@@ -84,8 +84,6 @@ typedef unsigned int SVINDEX ;
 using namespace std;
 
 #include "tnt/tnt.h"
-#include "tnt/vec.h"
-#include "tnt/cmat.h"
 #include "memblock.h"
 
 using namespace TNT;
@@ -106,6 +104,7 @@ const real SInfinity = 1.0e7; // "small infinity" for boundary points (to avoid
 
 #define sqr_(a) ((a)*(a))
 #define min_(a,b) ((a)<(b)?(a):(b))
+#define max_(a,b) ((a)>(b)?(a):(b))
 double ElapsedTime();
 void   ResetTime() ;
 
