@@ -1,27 +1,27 @@
 /**************************************************************************
 
-    begin                : April 30 2004
-	version				 : 1.0 
+    begin                : June 30 2004
+	version				 : 1.2 
     copyright            : (C) 2004 by Gleb Beliakov
     email                : gleb@deakin.edu.au
 
-     This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
 
   Interpol.cpp: implementation of the STCInterpolant class.
 
+ *                                                                         *
+ * This program is free software; you can redistribute it and/or modify it *
+ * under the terms of the GNU General Public License as published by the   *
+ * Free Software Foundation; either version 2 of the License, or (at your  *
+ * option) any later version.                                              *
+ *                                                                         *
+ * This program is distributed in the hope that it will be useful, but     *
+ * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+ * General Public License for more details.                                *
+ *                                                                         *
+ * You should have received a copy of the GNU General Public License       *
+ * along with this program; if not, write to the Free Software Foundation, *
+ * Inc., 59 Temple Place Suite 330, Boston, MA 02111-1307 USA.             *
  ***************************************************************************/
 
 #include "interpol.h"
@@ -37,7 +37,7 @@ Interpolant*	Parent;
 double merge(double a, double b)
 {
 	double c;
-	ULINT  d=(d2ulint(a) & ULLMASK) | (d2ulint(b)>>32);
+	ULINT  d=(d2ulint(a) & ULLMASK) | ((d2ulint(b)>>32) & ~ULLMASK);  // fixed in version 1.2
 	c=ulint2d(d);
 	return c;
 }
@@ -641,11 +641,11 @@ real	STCInterpolant::DetermineLipschitz()
 
 		u=0;
 		for(i=0;i<Dim;i++) {
-			Lip2[i]=Lip1[i]=max(Lip1[i],Lip2[i])*1.000001;
-			u=max(u,Lip1[i]);
+			Lip2[i]=Lip1[i]=TNT::max(Lip1[i],Lip2[i])*1.000001;
+			u=TNT::max(u,Lip1[i]);
 		}
 
-		LipschitzConst=max(u,1e-5);
+		LipschitzConst=TNT::max(u,1e-5);
 		return LipschitzConst;
 }
 
